#include <iostream>
#include <vector>

using namespace std;

struct Animal {
    int dirX, dirY;
    int x, y;
    int timeIndex = 0;
    bool dead = false;
};

struct Tile {
    Animal * wolf = NULL;
    Animal * sheep = NULL;
    int timeIndex = 0;
    bool dead = false;
    bool grass = false;
};

struct Board {
    Tile * tiles;

    int rows;
    int cols;

    Board(int rows, int cols) {
        this->rows = rows;
        this->cols = cols;
        tiles = new Tile[rows * cols];

        for(int i = 0; i < rows * cols; ++i) {
            tiles[i] = {
                    NULL, NULL, 0, false, false
            };
        }
    }

    ~Board() {
        delete[] tiles;
    }

    Tile & getTile(int x, int y) {
        return tiles[y * cols + x];
    }
};

int main() {

    int numOfTurns, numOfRows, numOfColumns;

    cin >> numOfTurns >> numOfRows >> numOfColumns;

    Board board(numOfRows, numOfColumns);

    vector<Animal> wolves;
    vector<Animal> sheeps;

    char c;
    for(int y = 0; y < numOfRows; ++y) {
        for(int x = 0; x < numOfColumns; ++x) {
           cin >> c;

           if(c == 'S') {
               sheeps.push_back({0, 1, x, y, 0});
           } else if (c == 'W') {
               wolves.push_back({1, 0, x, y, 0});
           }
        }
    }

    for(int moveIndex = 0; moveIndex < numOfTurns; ++moveIndex) {

        for(int y = 0; y < numOfRows; ++y) {
            for(int x = 0; x < numOfColumns; ++x) {
                Tile & t = board.getTile(x, y);

                if(t.grass == false) {
                    ++(t.timeIndex);
                }

                if(t.dead == false && t.timeIndex > 3 && t.grass == false) {
                    t.grass = true;
                    t.timeIndex = 0;
                }

                t.wolf = NULL;
                t.sheep = NULL;
            }
        }

        for(Animal & wolf : wolves) {
            if(wolf.dead) continue;

            ++wolf.timeIndex;
            if(wolf.timeIndex > 10) {
                wolf.dead = true;
                Tile & t = board.getTile(wolf.x, wolf.y);
                t.dead = true;
                t.wolf = NULL;
            } else {
                if(wolf.x + wolf.dirX >= numOfColumns) {
                    wolf.x = -1;
                }

                wolf.x += wolf.dirX;
                board.getTile(wolf.x, wolf.y).wolf = &wolf;
            }
        }

        for(Animal & sheep : sheeps) {
            if(sheep.dead) continue;

            ++sheep.timeIndex;
            if(sheep.timeIndex > 5) {
                sheep.dead = true;
                Tile & t = board.getTile(sheep.x, sheep.y);
                t.dead = true;
                t.sheep = NULL;
            } else {
                if(sheep.y + sheep.dirY >= numOfRows) {
                    sheep.y = -1;
                }

                sheep.y += sheep.dirY;

                Tile & t = board.getTile(sheep.x, sheep.y);
                if(t.wolf != NULL) {
                    sheep.dead = true;
                    t.wolf->timeIndex = 0;
                    t.dead = true;
                    t.sheep = NULL;
                } else if(t.grass == true && t.dead == false) {
                    sheep.timeIndex = 0;
                    t.grass = false;
                    t.timeIndex = 0;
                    t.sheep = &sheep;
                } else {
                    t.sheep = &sheep;
                }
            }
        }
//        for(int y = 0; y < numOfRows; ++y) {
//            for(int x = 0; x < numOfColumns; ++x) {
//                Tile & t = board.getTile(x, y);
//
//                if(t.wolf != NULL) {
//                    cout << "W";
//                } else if(t.sheep != NULL) {
//                    cout << "S";
//                } else if(t.dead) {
//                    cout << "*";
//                } else if(t.grass) {
//                    cout << "#";
//                } else {
//                    cout << ".";
//                }
//            }
//            cout << endl;
//        }
//        cout << endl;
//        cout << endl;
    }

    for(int y = 0; y < numOfRows; ++y) {
        for(int x = 0; x < numOfColumns; ++x) {
            Tile & t = board.getTile(x, y);

            if(t.wolf != NULL) {
                cout << "W";
            } else if(t.sheep != NULL) {
                cout << "S";
            } else if(t.dead) {
                cout << "*";
            } else if(t.grass) {
                cout << "#";
            } else {
                cout << ".";
            }
        }
        cout << endl;
    }

    return 0;
}